@@ -1,7 +1,7 @@
 package GIS::Distance::GreatCircle;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Math::Trig qw( deg2rad asin );
 use GIS::Distance::Constants qw( :all );
@@ -52,10 +52,6 @@ is used which in turn interfaces with the various formula modules.
         ( sin(( lon1 - lon2 )/2) )**2
     ) )
 
-=head1 SEE ALSO
-
-L<GIS::Distanc>
-
 =head1 AUTHORS AND LICENSE
 
 See L<GIS::Distance/AUTHORS> and L<GIS::Distance/LICENSE>.
